km3modules.k40.TwofoldCounter
=============================

.. currentmodule:: km3modules.k40

.. autoclass:: TwofoldCounter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TwofoldCounter.__init__
      ~TwofoldCounter.add
      ~TwofoldCounter.configure
      ~TwofoldCounter.dump
      ~TwofoldCounter.expose
      ~TwofoldCounter.finish
      ~TwofoldCounter.get
      ~TwofoldCounter.get_livetime
      ~TwofoldCounter.pre_finish
      ~TwofoldCounter.process
      ~TwofoldCounter.require
      ~TwofoldCounter.reset
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TwofoldCounter.name
   
   